0.10.2 (2022-10-16)
===================

Features
--------

- Update core addon lists. (`#30 <https://github.com/sbidoul/manifestoo-core/issues/30>`_)


0.10.1 (2022-09-21)
===================

Features
--------

- Update core addon lists. (`#25 <https://github.com/sbidoul/manifestoo-core/issues/25>`_, `#27 <https://github.com/sbidoul/manifestoo-core/issues/27>`_)


0.10 (2022-08-31)
=================

Features
--------

- ``metadata_from_addon_dir``: better detection of invalid addon directories. (`#9 <https://github.com/sbidoul/manifestoo-core/issues/9>`_)
- Update core addon lists. (`#21 <https://github.com/sbidoul/manifestoo-core/issues/21>`_)


0.9 (2022-07-08)
================

Features
--------

- New ``is_addon_dir`` function. (`#10 <https://github.com/sbidoul/manifestoo-core/issues/10>`_)


0.8 (2022-05-26)
================

Features
--------

- Add ``manifestoo_core.metadata.metadata_from_addon_dir`` function to produce
  Python standard package metadata 2.2 from the addon manifest.


0.7 (2022-05-21)
================

Features
--------

- Restore python 3.6 support. (`#7 <https://github.com/sbidoul/manifestoo-core/issues/7>`_)


0.6 (2022-05-21)
================

Improved Documentation
----------------------

- Document the `core_addons` and `odoo_series` modules. (`#6 <https://github.com/sbidoul/manifestoo-core/issues/6>`_)


0.5.2 (2022-05-21)
==================

Features
--------

- Update core addon lists. (`#5 <https://github.com/sbidoul/manifestoo-core/issues/5>`_)

Removals
--------

- Drop python 3.6 support. (`#2 <https://github.com/sbidoul/manifestoo-core/pull/2>`_)


0.5.0 (2022-05-18)
==================

First release.
